@@ -100,21 +100,27 @@ class ACICacheControllerABC(metaclass=ABCMeta):
 
     def _loadDataIntoCache(self, encodedChunkTuples: List[ACIEncodedChunkTupleABC]):
         chunkKeysUpdated: List[str] = []
+        deletedCount = 0
+        updatedCount = 0
 
         for t in encodedChunkTuples:
             if not t.ckiHasEncodedData:
                 if t.ckiChunkKey in self._cache:
+                    deletedCount += 1
                     del self._cache[t.ckiChunkKey]
                     chunkKeysUpdated.append(t.ckiChunkKey)
                 continue
 
             if (not t.ckiChunkKey in self._cache or
                     self._cache[t.ckiChunkKey].ckiLastUpdate != t.ckiLastUpdate):
+                updatedCount += 1
                 self._cache[t.ckiChunkKey] = t
                 chunkKeysUpdated.append(t.ckiChunkKey)
 
-        self._logger.debug("Received %s updates from server, %s had changed",
-                           len(chunkKeysUpdated), len(chunkKeysUpdated))
+        self._logger.debug("Received %s updates from server"
+                           ", %s had changed"
+                           ", %s were deleted",
+                           len(encodedChunkTuples), updatedCount, deletedCount)
 
         self._notifyOfChunkKeysUpdated(chunkKeysUpdated)
 
